@@ -7,11 +7,9 @@ from typing import List, Optional
 
 
 # dependencies
-from arxiv import Result  # type: ignore
-
-
-# submodules
-from .detex import detex
+import re
+from arxiv import Result
+from pylatexenc.latex2text import LatexNodes2Text
 
 
 # constants
@@ -41,7 +39,7 @@ class Article:
     def from_arxiv_result(cls, result: Result) -> "Article":
         return Article(
             title=result.title,
-            authors=[a.name for a in result.authors],  # type: ignore
+            authors=[a.name for a in result.authors],
             summary=result.summary,
             arxiv_url=str(result),
         )
@@ -52,3 +50,10 @@ class Article:
 
     def __str__(self) -> str:
         return f"{self.title}\n{TITLE_SUMMARY_DIV}\n{self.summary}"
+
+
+# runtime functions
+def detex(text: str) -> str:
+    """Remove TeX's control commands from a text."""
+    text = re.sub(r"(\n+\s*|\n*\s+)", " ", text)
+    return LatexNodes2Text().latex_to_text(text)
